@@ -60,7 +60,7 @@ class LogHandle(object):
         if not isinstance(file_dir, (str, type(None))):
             raise Exception("'file_dir' is missing")
         if file_dir and not os.path.exists(file_dir):
-            raise Exception("'file_dir' does not exist")
+            os.makedirs(file_dir)
 
         self.__file_dir = file_dir
 
